Package: bioLeak
Type: Package
Title: Leakage-Safe Modeling and Auditing for Genomic and Clinical Data
Version: 0.3.8
Authors@R: c(
    person("Selcuk", "Korkmaz", role = c("aut","cre"), email = "selcukorkmaz@gmail.com",
           comment = c(ORCID = "0000-0003-4632-6850"))
    )
Description: Prevents and detects information leakage in biomedical machine learning.
  Provides leakage-resistant split policies (subject-grouped, batch-blocked, study leave-out, time-ordered),
  guarded preprocessing (train-only imputation, normalization, filtering, feature selection),
  cross-validated fitting with common learners, permutation-gap auditing, batch and fold association tests,
  and duplicate detection.
License: MIT + file LICENSE
URL: https://github.com/selcukorkmaz/bioLeak
BugReports: https://github.com/selcukorkmaz/bioLeak/issues
Encoding: UTF-8
Depends: R (>= 4.3)
Imports: digest, generics, methods, stats, utils, SummarizedExperiment,
        graphics, hardhat, parsnip
Suggests: BiocParallel, splitGraph, cli, dials, FNN, future,
        future.apply, ggplot2, glmnet, mice, missForest, pkgload,
        ranger, randomForest, recipes, RANN, rsample, tune, VIM, withr,
        workflows, xgboost, yardstick, pROC, PRROC, survival, knitr,
        rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
RoxygenNote: 7.3.3
Collate: 'classes.R' 'accessors.R' 'audit.R' 'audit_report.R'
        'benchmark_suite.R' 'ci_delta.R' 'conditions.R'
        'cv_uncertainty.R' 'cvauc_if.R' 'delta_lsi.R'
        'diagnostics_extra.R' 'fit_resample.R' 'globals.R'
        'guard_to_recipe.R' 'guards.R' 'imports.R' 'impute_guarded.R'
        'make_split_plan.R' 'permute_labels.R' 'plotting_audit.R'
        'provenance.R' 'simulate_suite.R' 'splitgraph_adapter.R'
        'summary.R' 'tidymodels.R' 'time_series_blocks.R'
        'tune_resample.R' 'utils_metrics.R' 'utils_print.R'
        'utils_se.R'
NeedsCompilation: no
Packaged: 2026-05-21 18:14:56 UTC; selcuk
Author: Selcuk Korkmaz [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4632-6850>)
Maintainer: Selcuk Korkmaz <selcukorkmaz@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-21 18:40:02 UTC
Built: R 4.5.2; ; 2026-05-25 02:05:10 UTC; unix
