# Generated by roxygen2: do not edit by hand

S3method(as_rsample,LeakSplits)
S3method(predict,GuardFit)
S3method(print,GuardFit)
S3method(print,LeakAuditList)
S3method(print,LeakTune)
S3method(print,summary.GuardFit)
S3method(summary,GuardFit)
S3method(summary,LeakAudit)
S3method(summary,LeakDeltaLSI)
S3method(summary,LeakFit)
S3method(summary,LeakTune)
export(as_leaksplits)
export(as_rsample)
export(audit_batch_assoc)
export(audit_duplicates)
export(audit_info)
export(audit_leakage)
export(audit_leakage_by_learner)
export(audit_perm_gap)
export(audit_report)
export(audit_target_assoc)
export(benchmark_leakage_suite)
export(calibration_summary)
export(check_split_overlap)
export(confounder_sensitivity)
export(cv_ci)
export(delta_lsi)
export(dlsi_R_eff)
export(dlsi_ci)
export(dlsi_metric)
export(dlsi_p_value)
export(dlsi_repeats)
export(dlsi_robust)
export(dlsi_tier)
export(fit_metrics)
export(fit_resample)
export(guard_ensure_levels)
export(guard_fit)
export(guard_to_recipe)
export(impute_guarded)
export(make_split_plan)
export(plot_calibration)
export(plot_confounder_sensitivity)
export(plot_dlsi_repeats)
export(plot_fold_balance)
export(plot_overlap_checks)
export(plot_perm_distribution)
export(plot_time_acf)
export(predict_guard)
export(simulate_leakage_suite)
export(tune_resample)
exportClasses(LeakAudit)
exportClasses(LeakDeltaLSI)
exportClasses(LeakFit)
exportClasses(LeakSplits)
exportMethods(audit_batch_assoc)
exportMethods(audit_duplicates)
exportMethods(audit_info)
exportMethods(audit_perm_gap)
exportMethods(audit_target_assoc)
exportMethods(dlsi_R_eff)
exportMethods(dlsi_ci)
exportMethods(dlsi_metric)
exportMethods(dlsi_p_value)
exportMethods(dlsi_repeats)
exportMethods(dlsi_robust)
exportMethods(dlsi_tier)
exportMethods(fit_metrics)
exportMethods(plot)
exportMethods(show)
importFrom(methods,new)
importFrom(stats,aggregate)
importFrom(stats,ave)
importFrom(stats,predict)
importFrom(stats,rbinom)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(utils,head)
importFrom(utils,modifyList)
importMethodsFrom(methods,show)
