% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/accessors.R
\name{audit_batch_assoc}
\alias{audit_batch_assoc}
\title{Batch / study association results from a LeakAudit}
\usage{
audit_batch_assoc(audit)
}
\arguments{
\item{audit}{A `LeakAudit` object returned by [audit_leakage()].}
}
\value{
A `data.frame` (possibly empty) with one row per
  (metadata column, repeat).
}
\description{
Returns the batch/study chi-squared association data frame stored in
a `LeakAudit` object. Columns include the metadata column, repeat,
chi-squared statistic, degrees of freedom, p-value, and Cramer's V.
}
\seealso{
[audit_leakage()], [audit_perm_gap()]
}
