% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/accessors.R
\name{dlsi_repeats}
\alias{dlsi_repeats}
\title{Per-repeat metric data frames from a LeakDeltaLSI}
\usage{
dlsi_repeats(dlsi, which = c("naive", "guarded"))
}
\arguments{
\item{dlsi}{A `LeakDeltaLSI` object returned by [delta_lsi()].}

\item{which}{Either `"naive"` (default) for the naive/leaky
pipeline's per-repeat data frame, or `"guarded"` for the guarded
pipeline's per-repeat data frame.}
}
\value{
A `data.frame` with one row per repeat.
}
\description{
Returns the per-repeat metric data frame for one of the two
pipelines stored in a `LeakDeltaLSI` object. The naive (or leaky)
pipeline's repeats are returned by default; set
`which = "guarded"` to return the guarded pipeline's repeats.
}
\seealso{
[delta_lsi()]
}
